# Pokemanager

<div align="center">

<img src="docs\assets\pokemanager-logo.svg" alt="Pokemanager Logo"></br>

[![Release](https://img.shields.io/github/v/release/ethanshanahan/pokemanager?label=Release)](https://github.com/ethanshanahan/pokemanager/releases/latest)
[![Docs](https://github.com/ethan-shanahan/pokemanager/actions/workflows/docs.yml/badge.svg)](https://ethan-shanahan.github.io/pokemanager/)
[![License](https://img.shields.io/github/license/ethan-shanahan/pokemanager?label=License)](https://www.gnu.org/licenses/gpl-3.0.en.html)

</div>

**Pokemanager** is your very own **command-line PC**. Just like the PC, you can save a collection of Pokémon, but Pokemanager goes above and beyond to provide a whole host of analysis tools to boot.

> [!WARNING]
> Pokemanager is in alpha and as such, most features are not implemented or may be broken. Use at your own risk.

## Features

- Save your Pokémon data locally to reuse at any time or even share with others.
- Integrate with Google Sheets to conveniently display your Pokémon and update your collection.
- Analyse your Pokémon individually to plan training, move sets, etc.
- Analyse your Pokémon collectively to devise teams for various purposes.
- Compartmentalise your collection to track Pokémon in:
  - different generational contexts
  - Nuzlocke playthroughs
  - Soullink Nuzlocke playthroughs

Read all about what Pokemanager has to offer and how best to use it in the [documentation](https://ethan-shanahan.github.io/pokemanager/).

## Install

You can easily install Pokemanager from the [Python Package Index](https://pypi.org/project/pokemanager/). If you have Python already installed, this is likely as simple as:

```sh
pip install pokemanager
```

But feel free to use whatever package manager you like.

If you instead decide to clone this repository for the development build or environment, then I recommend using [Pixi](https://pixi.sh/latest/) like so:

```sh
pixi install
```
